# peppy python package

![Run pytests](https://github.com/pepkit/peppy/workflows/Run%20pytests/badge.svg)
[![codecov](https://codecov.io/gh/pepkit/peppy/branch/master/graph/badge.svg)](https://codecov.io/gh/pepkit/peppy)
[![PEP compatible](https://pepkit.github.io/img/PEP-compatible-green.svg)](https://pep.databio.org)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

`peppy` is the official python package for reading **Portable Encapsulated Projects** or **PEP**s in Python.

Links to complete documentation:

* Complete documentation and API for the `peppy` python package is at [peppy.databio.org](https://peppy.databio.org).
* Reference documentation for standard **PEP** format is at [pep.databio.org](https://pep.databio.org/).
* Example PEPs for testing `peppy` are in the [example_peps repository](https://github.com/pepkit/example_peps).
* The package [on PyPI](https://pypi.org/project/peppy/).
